@@ -51,7 +51,7 @@ class Exceptions:
 
 class SSOOIDCClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sso-oidc.html#SSOOIDC.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -60,8 +60,8 @@ class SSOOIDCClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_token(
@@ -76,8 +76,8 @@ class SSOOIDCClient:
         redirectUri: str = None,
     ) -> CreateTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
-        [Show boto3-stubs documentation](./client.md#create-token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        [Show boto3-stubs documentation](./client.md#create_token)
         """
 
     def generate_presigned_url(
@@ -88,22 +88,22 @@ class SSOOIDCClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def register_client(
         self, clientName: str, clientType: str, scopes: List[str] = None
     ) -> RegisterClientResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
-        [Show boto3-stubs documentation](./client.md#register-client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        [Show boto3-stubs documentation](./client.md#register_client)
         """
 
     def start_device_authorization(
         self, clientId: str, clientSecret: str, startUrl: str
     ) -> StartDeviceAuthorizationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
-        [Show boto3-stubs documentation](./client.md#start-device-authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        [Show boto3-stubs documentation](./client.md#start_device_authorization)
         """
